@@ -1,3 +1,5 @@
+#include <features.h>
+
 struct k_sigaction {
 	unsigned flags;
 	void (*handler)(int);
@@ -8,4 +10,4 @@ struct k_sigaction {
 	void (*restorer)();
 };
 
-void __restore(), __restore_rt();
+hidden void __restore(), __restore_rt();
