@@ -3,7 +3,6 @@
 #include <stddef.h>
 #include "__dirent.h"
 #include "syscall.h"
-#include "libc.h"
 
 typedef char dirstream_buf_alignment_check[1-2*(int)(
 	offsetof(struct __dirstream, buf) % sizeof(off_t))];
@@ -27,4 +26,4 @@ struct dirent *readdir(DIR *dir)
 	return de;
 }
 
-LFS64(readdir);
+weak_alias(readdir, readdir64);
